@@ -43,6 +43,7 @@ MagnetView::MagnetView(MagnetManager *magnetManager, QWidget *parent)
     view->setAllColumnsShowFocus(true);
     view->setSelectionMode(QAbstractItemView::ContiguousSelection);
     view->setContextMenuPolicy(Qt::CustomContextMenu);
+    view->setProperty("_breeze_borders_sides", QVariant::fromValue(QFlags<Qt::Edge>{Qt::BottomEdge}));
     connect(view, &QTreeView::customContextMenuRequested, this, &MagnetView::showContextMenu);
     layout->addWidget(view);
 
@@ -61,7 +62,7 @@ MagnetView::~MagnetView()
 
 void MagnetView::loadState(KSharedConfigPtr cfg)
 {
-    KConfigGroup g = cfg->group("MagnetView");
+    KConfigGroup g = cfg->group(QStringLiteral("MagnetView"));
     QByteArray s = QByteArray::fromBase64(g.readEntry("state", QByteArray()));
     if (!s.isEmpty()) {
         QHeaderView *v = view->header();
@@ -71,7 +72,7 @@ void MagnetView::loadState(KSharedConfigPtr cfg)
 
 void MagnetView::saveState(KSharedConfigPtr cfg)
 {
-    KConfigGroup g = cfg->group("MagnetView");
+    KConfigGroup g = cfg->group(QStringLiteral("MagnetView"));
     g.writeEntry("state", view->header()->saveState().toBase64());
 }
 
